@@ -110,6 +110,14 @@ which app state variables are finally used by your app project is (fully data-dr
 names of all the available application state variables can be determined with the main app helper method
 :meth:`~MainAppBase.app_state_keys`.
 
+if no config-file is provided then this package ensures at least the proper initialization of the following
+app state variables:
+
+    * :attr:`~MainAppBase.font_size`
+    * :attr:`~MainAppBase.lang_code`
+    * :attr:`~MainAppBase.light_theme`
+    * :attr:`~MainAppBase.win_rectangle`
+
 if your application is e.g. supporting a user-defined font size, using the provided/pre-defined app state variable
 :attr:`~MainAppBase.font_size`, then it has to call the method :meth:`change_app_state` with the argument of
 :paramref:`~MainAppBase.change_app_state.app_state_name` set to `font_size` every time when the user has changed the
@@ -252,28 +260,28 @@ normalized modifiers and key args.
 the :paramref:`~MainAppBase.key_press_from_framework.modifiers` arg is a string that can contain several of the
 following sub-strings, always in the alphabetic order (like listed below):
 
-* Alt
-* Ctrl
-* Meta
-* Shift
+    * Alt
+    * Ctrl
+    * Meta
+    * Shift
 
 the :paramref:`~MainAppBase.key_press_from_framework.key` arg is a string that is specifying the last pressed key. if
 the key is not representing a single character but a command key, then `key` will be one of the following strings:
 
-* escape
-* tab
-* backspace
-* enter
-* del
-* enter
-* up
-* down
-* right
-* left
-* home
-* end
-* pgup
-* pgdown
+    * escape
+    * tab
+    * backspace
+    * enter
+    * del
+    * enter
+    * up
+    * down
+    * right
+    * left
+    * home
+    * end
+    * pgup
+    * pgdown
 
 on call of :meth:`~MainAppBase.key_press_from_framework` this method will try to dispatch the key press event to your
 application. first it will check the app instance if it has declared a method with the name
@@ -370,6 +378,11 @@ the sound files provides by this portion are taken from:
 * `plasterbrain <https://freesound.org/people/plasterbrain/>`_ at `freesound.org <https://freesound.org>`_.
 
 .. hint:: the i18n translation texts of this module are provided by the ae namespace portion :mod:`ae.gui_help`.
+
+TODO:
+implement OS-independent detection of dark/light screen mode and automatic notification on day/night mode switch.
+- see https://github.com/albertosottile/darkdetect for MacOS, MSWindows and Ubuntu
+- see https://github.com/kvdroid/Kvdroid/blob/master/kvdroid/tools/darkmode.py for Android
 """
 import os
 import re
@@ -380,20 +393,20 @@ from typing import Any, Callable, Dict, List, Optional, Tuple, Type, Union
 
 from ae.base import (                                                                                   # type: ignore
     CFG_EXT, INI_EXT, NAME_PARTS_SEP, UNSET,
-    instantiate_config_parser, norm_name, norm_path, now_str, os_platform, snake_to_camel)
+    instantiate_config_parser, norm_name, norm_path, now_str, os_platform, snake_to_camel, stack_var)
 from ae.files import RegisteredFile                                                                     # type: ignore
 from ae.paths import (                                                                                  # type: ignore
     add_common_storage_paths, copy_file, copy_tree, normalize, path_folders, path_name, placeholder_path,
     Collector, FilesRegister, placeholder_key)
 from ae.updater import MOVES_SRC_FOLDER_NAME, check_all                                                 # type: ignore
-from ae.inspector import stack_var, try_call                                                            # type: ignore
+from ae.dynamicod import try_call                                                                       # type: ignore
 from ae.i18n import (                                                                                   # type: ignore
     default_language, get_f_string, get_text, load_language_texts, register_translations_path)
 from ae.core import DEBUG_LEVELS, registered_app_names                                                  # type: ignore
 from ae.console import ConsoleApp                                                                       # type: ignore
 
 
-__version__ = '0.3.87'
+__version__ = '0.3.88'
 
 
 APP_STATE_SECTION_NAME = 'aeAppState'           #: config section name to store app state
@@ -609,11 +622,11 @@ def id_of_flow(action: str, obj: str = "", key: str = "") -> str:
 def register_package_images():
     """ call from module scope of the package to register/add image/img resources path.
 
-    no parameters needed because we use here :func:`~ae.inspector.stack_var` helper function to determine the
+    no parameters needed because we use here :func:`~ae.base.stack_var` helper function to determine the
     module file path via the `__file__` module variable of the caller module in the call stack. in this call
-    we have to overwrite the default value (:data:`~ae.inspector.SKIPPED_MODULES`) of the
-    :paramref:`~ae.inspector.stack_var.skip_modules` parameter to not skip ae portions that are providing
-    package resources and are listed in the :data:`~ae.inspector.SKIPPED_MODULES`, like e.g. :mod:`ae.gui_app` and
+    we have to overwrite the default value (:data:`~ae.base.SKIPPED_MODULES`) of the
+    :paramref:`~ae.base.stack_var.skip_modules` parameter to not skip ae portions that are providing
+    package resources and are listed in the :data:`~ae.base.SKIPPED_MODULES`, like e.g. :mod:`ae.gui_app` and
     :mod:`ae.gui_help` (passing empty string '' to overwrite default skip list).
     """
     global PORTIONS_IMAGES
@@ -626,11 +639,11 @@ def register_package_images():
 def register_package_sounds():
     """ call from module scope of the package to register/add sound file resources.
 
-    no parameters needed because we use here :func:`~ae.inspector.stack_var` helper function to determine the
+    no parameters needed because we use here :func:`~ae.base.stack_var` helper function to determine the
     module file path via the `__file__` module variable of the caller module in the call stack. in this call
-    we have to overwrite the default value (:data:`~ae.inspector.SKIPPED_MODULES`) of the
-    :paramref:`~ae.inspector.stack_var.skip_modules` parameter to not skip ae portions that are providing
-    package resources and are listed in the :data:`~ae.inspector.SKIPPED_MODULES`, like e.g. :mod:`ae.gui_app`
+    we have to overwrite the default value (:data:`~ae.base.SKIPPED_MODULES`) of the
+    :paramref:`~ae.base.stack_var.skip_modules` parameter to not skip ae portions that are providing
+    package resources and are listed in the :data:`~ae.base.SKIPPED_MODULES`, like e.g. :mod:`ae.gui_app`
     :mod:`ae.gui_help` (passing empty string '' to overwrite default skip list).
     """
     global PORTIONS_SOUNDS
@@ -927,8 +940,6 @@ class MainAppBase(ConsoleApp, ABC):
     def class_by_name(class_name: str) -> Optional[Type]:
         """ search class name in framework modules as well as in app main.py to return class object.
 
-        fallback using the :mod:`ae.inspector` module - overwrite in your app project to customize.
-
         :param class_name:      name of the class.
         :return:                class object with the specified class name or :data:`~ae.base.UNSET` if not found.
         """
@@ -1021,7 +1032,7 @@ class MainAppBase(ConsoleApp, ABC):
         glo_vars.update((k, v) for k, v in globals().items() if k not in HIDDEN_GLOBALS)
         glo_vars['app'] = self.framework_app
         glo_vars['main_app'] = self
-        glo_vars['_add_base_globals'] = ""          # instruct ae.inspector.try_eval to add generic/base globals
+        glo_vars['_add_base_globals'] = ""          # instruct ae.dynamicod.try_eval to add generic/base globals
 
         self.vpo(f"MainAppBase.global_variables patching {patches} over {glo_vars}")
 
